# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/configurator/v1/configurator.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/configurator/v1/configurator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'tars/configurator/v1/configurator.proto\x12\x14tars.configurator.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x17tars/docs/v1/docs.proto\"Z\n\x17GetConfigurationRequest\x12?\n\x07queries\x18\x01 \x03(\x0b\x32%.tars.configurator.v1.UserConfigQueryR\x07queries\"\xad\x01\n\x0fUserConfigQuery\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x02 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\'\n\x0f\x63urrent_version\x18\x03 \x01(\x03R\x0e\x63urrentVersion\x12\x15\n\x06key_id\x18\x04 \x01(\tR\x05keyId\"g\n\x18GetConfigurationResponse\x12K\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32#.tars.configurator.v1.ConfigurationR\x0e\x63onfigurations\"\xaf\x02\n\x14TriggerUpdateRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x02 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12>\n\nevent_type\x18\x03 \x01(\x0e\x32\x1f.tars.configurator.v1.EventTypeR\teventType\x12\x15\n\x06key_id\x18\x04 \x01(\tR\x05keyId\x12!\n\x0cworkspace_id\x18\x05 \x01(\tR\x0bworkspaceId\x12\x41\n\x08metadata\x18\x06 \x01(\x0b\x32%.tars.configurator.v1.TriggerMetadataR\x08metadata\"m\n\x0fTriggerMetadata\x12Z\n\x11\x64\x61taplane_upgrade\x18\x01 \x01(\x0b\x32-.tars.configurator.v1.DataplaneUpgradeTriggerR\x10\x64\x61taplaneUpgrade\"\x82\x02\n\x17\x44\x61taplaneUpgradeTrigger\x12%\n\x0etarget_version\x18\x01 \x01(\tR\rtargetVersion\x12%\n\x0e\x61llow_downtime\x18\x02 \x01(\x08R\rallowDowntime\x12\'\n\x0f\x63redentials_ref\x18\x03 \x01(\tR\x0e\x63redentialsRef\x12,\n\x12persist_in_cluster\x18\x04 \x01(\x08R\x10persistInCluster\x12\x42\n\x1d\x61\x63knowledged_preflight_checks\x18\x05 \x03(\tR\x1b\x61\x63knowledgedPreflightChecks\"\x97\x01\n\x15TriggerUpdateResponse\x12I\n\rconfiguration\x18\x01 \x01(\x0b\x32#.tars.configurator.v1.ConfigurationR\rconfiguration\x12\x33\n\x15\x63onfiguration_updated\x18\x02 \x01(\x08R\x14\x63onfigurationUpdated\"\xb3\x01\n\x19ListConfigurationsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x02 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\"\x91\x01\n\x1aListConfigurationsResponse\x12K\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32#.tars.configurator.v1.ConfigurationR\x0e\x63onfigurations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x82\x01\n\x18ListPendingEventsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12P\n\x0e\x64octor_runtime\x18\x02 \x01(\x0b\x32).tars.configurator.v1.DoctorRuntimeStatusR\rdoctorRuntime\"\x90\x02\n\x13\x44octorRuntimeStatus\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12!\n\x0ctare_version\x18\x02 \x01(\tR\x0btareVersion\x12\x14\n\x05state\x18\x03 \x01(\tR\x05state\x12\x16\n\x06reason\x18\x04 \x01(\tR\x06reason\x12J\n\x13last_successful_run\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11lastSuccessfulRun\x12;\n\x0bobserved_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nobservedAt\"]\n\x19ListPendingEventsResponse\x12@\n\x06\x65vents\x18\x01 \x03(\x0b\x32(.tars.configurator.v1.ConfigurationEventR\x06\x65vents\"\x1b\n\x19ReconcileWorkspaceRequest\"\xd2\x01\n\x1aReconcileWorkspaceResponse\x12%\n\x0ereplayed_total\x18\x01 \x01(\x05R\rreplayedTotal\x12\'\n\x0freplayed_global\x18\x02 \x01(\x05R\x0ereplayedGlobal\x12*\n\x11replayed_per_user\x18\x03 \x01(\x05R\x0freplayedPerUser\x12\x38\n\x19replayed_per_user_per_key\x18\x04 \x01(\x05R\x15replayedPerUserPerKey\"\x1a\n\x18\x46ullSyncWorkspaceRequest\"\xa8\x01\n\x19\x46ullSyncWorkspaceResponse\x12%\n\x0ereplayed_total\x18\x01 \x01(\x05R\rreplayedTotal\x12*\n\x11replayed_per_user\x18\x02 \x01(\x05R\x0freplayedPerUser\x12\x38\n\x19replayed_per_user_per_key\x18\x03 \x01(\x05R\x15replayedPerUserPerKey\"\xb1\x03\n\x12\x43onfigurationEvent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x03 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\x1d\n\nevent_type\x18\x04 \x01(\tR\teventType\x12\x15\n\x06key_id\x18\x05 \x01(\tR\x05keyId\x12\x1b\n\tconfig_id\x18\x06 \x01(\tR\x08\x63onfigId\x12%\n\x0e\x63onfig_version\x18\x07 \x01(\x03R\rconfigVersion\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12=\n\x0ctriggered_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btriggeredAt\x12\x1f\n\x0bretry_count\x18\n \x01(\x05R\nretryCount\x12!\n\x0cworkspace_id\x18\x0b \x01(\tR\x0bworkspaceId\x12\x1a\n\x08metadata\x18\x0c \x01(\tR\x08metadata\"Q\n\x17\x41\x63knowledgeEventRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1b\n\tworker_id\x18\x02 \x01(\tR\x08workerId\"4\n\x18\x41\x63knowledgeEventResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"p\n\x14\x43ompleteEventRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\"1\n\x15\x43ompleteEventResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\".\n\x16ListActiveUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\"4\n\x17ListActiveUsersResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\"\xc3\x02\n\rConfiguration\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x41\n\x0b\x63onfig_type\x18\x03 \x01(\x0e\x32 .tars.configurator.v1.ConfigTypeR\nconfigType\x12\x1f\n\x0b\x63onfig_data\x18\x04 \x01(\tR\nconfigData\x12\x18\n\x07version\x18\x05 \x01(\x03R\x07version\x12\x15\n\x06key_id\x18\x06 \x01(\tR\x05keyId\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\xec\x01\n\x0fProviderBackend\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x1a\n\x08provider\x18\x03 \x01(\tR\x08provider\x12\x16\n\x06weight\x18\x04 \x01(\x05R\x06weight\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12\x1f\n\x0b\x62yok_policy\x18\x06 \x01(\tR\nbyokPolicy\x12\x1f\n\x0bis_external\x18\x07 \x01(\x08R\nisExternal\x12\x1d\n\nmodel_name\x18\x08 \x01(\tR\tmodelName\"\x96\x01\n\x17SaveBYOKBackendsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0bkey_address\x18\x02 \x01(\tR\nkeyAddress\x12\x41\n\x08\x62\x61\x63kends\x18\x03 \x03(\x0b\x32%.tars.configurator.v1.ProviderBackendR\x08\x62\x61\x63kends\"\x7f\n\x18SaveBYOKBackendsResponse\x12I\n\rconfiguration\x18\x01 \x01(\x0b\x32#.tars.configurator.v1.ConfigurationR\rconfiguration\x12\x18\n\x07updated\x18\x02 \x01(\x08R\x07updated\"4\n\x19\x44\x65leteBYOKBackendsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"6\n\x1a\x44\x65leteBYOKBackendsResponse\x12\x18\n\x07\x64\x65leted\x18\x01 \x01(\x08R\x07\x64\x65leted\"k\n\x16RevokeUserTokenRequest\x12\x10\n\x03jti\x18\x01 \x01(\tR\x03jti\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1b\n\x06reason\x18\x03 \x01(\tH\x00R\x06reason\x88\x01\x01\x42\t\n\x07_reason\"n\n\x17RevokeUserTokenResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\"\xb1\x02\n\x08Provider\x12\x12\n\x04slug\x18\x01 \x01(\tR\x04slug\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12 \n\x0c\x61pi_base_url\x18\x03 \x01(\tR\napiBaseUrl\x12\x1b\n\tauth_type\x18\x04 \x01(\tR\x08\x61uthType\x12\x1d\n\nis_enabled\x18\x05 \x01(\x08R\tisEnabled\x12\x1a\n\x08metadata\x18\x06 \x01(\tR\x08metadata\x12\x39\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\"\x1c\n\x1aListActiveProvidersRequest\"[\n\x1bListActiveProvidersResponse\x12<\n\tproviders\x18\x01 \x03(\x0b\x32\x1e.tars.configurator.v1.ProviderR\tproviders\"t\n\x16SetDataplaneURLRequest\x12!\n\x0cworkspace_id\x18\x01 \x01(\tR\x0bworkspaceId\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12%\n\x0etrigger_update\x18\x03 \x01(\x08R\rtriggerUpdate\"\x19\n\x17SetDataplaneURLResponse\"\xcb\x02\n\x1dUpsertMCPCatalogServerRequest\x12!\n\x0cworkspace_id\x18\x01 \x01(\tR\x0bworkspaceId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x10\n\x03url\x18\x03 \x01(\tR\x03url\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x19\n\x08icon_url\x18\x06 \x01(\tR\x07iconUrl\x12\x1e\n\ncategories\x18\x07 \x03(\tR\ncategories\x12&\n\x0e\x61uthentication\x18\x08 \x01(\tR\x0e\x61uthentication\x12#\n\rrequires_auth\x18\t \x01(\x08R\x0crequiresAuth\x12\'\n\x0f\x66orce_overwrite\x18\n \x01(\x08R\x0e\x66orceOverwrite\":\n\x1eUpsertMCPCatalogServerResponse\x12\x18\n\x07\x63reated\x18\x01 \x01(\x08R\x07\x63reated\"\x1a\n\x18ValidateDataplaneRequest\"|\n\x19ValidateDataplaneResponse\x12_\n\x16gatekeeper_public_keys\x18\x01 \x03(\x0b\x32).tars.configurator.v1.GatekeeperPublicKeyR\x14gatekeeperPublicKeys\"q\n\x13GatekeeperPublicKey\x12\x10\n\x03kid\x18\x01 \x01(\tR\x03kid\x12\x10\n\x03\x61lg\x18\x02 \x01(\tR\x03\x61lg\x12\x10\n\x03use\x18\x03 \x01(\tR\x03use\x12$\n\x0epublic_key_pem\x18\x04 \x01(\tR\x0cpublicKeyPem\"S\n\x1aUpdateEventMetadataRequest\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1a\n\x08metadata\x18\x02 \x01(\tR\x08metadata\"7\n\x1bUpdateEventMetadataResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"I\n\x1d\x43\x61ncelDataplaneUpgradeRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\":\n\x1e\x43\x61ncelDataplaneUpgradeResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\"K\n\x1fRollbackDataplaneUpgradeRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\"h\n RollbackDataplaneUpgradeResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12*\n\x11rollback_event_id\x18\x02 \x01(\tR\x0frollbackEventId\"\x84\x01\n\x1a\x44\x61taplaneUpgradeCredential\x12\x12\n\x04slot\x18\x01 \x01(\tR\x04slot\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x1a\n\x08registry\x18\x04 \x01(\tR\x08registry\"\xd6\x01\n(SubmitDataplaneUpgradeCredentialsRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\x12R\n\x0b\x63redentials\x18\x02 \x03(\x0b\x32\x30.tars.configurator.v1.DataplaneUpgradeCredentialR\x0b\x63redentials\x12,\n\x12persist_in_cluster\x18\x03 \x01(\x08R\x10persistInCluster\"l\n)SubmitDataplaneUpgradeCredentialsResponse\x12%\n\x0e\x63redentials_id\x18\x01 \x01(\tR\rcredentialsId\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\"Q\n%GetDataplaneUpgradeCredentialsRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\"\xc4\x01\n&GetDataplaneUpgradeCredentialsResponse\x12R\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32\x30.tars.configurator.v1.DataplaneUpgradeCredentialR\x0b\x63redentials\x12\x18\n\x07present\x18\x02 \x01(\x08R\x07present\x12,\n\x12persist_in_cluster\x18\x03 \x01(\x08R\x10persistInCluster\"o\n%AckDataplaneUpgradeCredentialsRequest\x12(\n\x10upgrade_event_id\x18\x01 \x01(\tR\x0eupgradeEventId\x12\x1c\n\tdelivered\x18\x02 \x01(\x08R\tdelivered\"B\n&AckDataplaneUpgradeCredentialsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success*\xa2\x03\n\nConfigType\x12\x1b\n\x17\x43ONFIG_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x43ONFIG_TYPE_GLOBAL_ROUTES\x10\x01\x12\x1b\n\x17\x43ONFIG_TYPE_USER_ROUTES\x10\x02\x12\x14\n\x10\x43ONFIG_TYPE_BYOK\x10\x03\x12\x1b\n\x17\x43ONFIG_TYPE_MCP_PROFILE\x10\x04\x12\x1c\n\x18\x43ONFIG_TYPE_MCP_BACKENDS\x10\x05\x12\x1b\n\x17\x43ONFIG_TYPE_OAUTH_TOKEN\x10\x06\x12\x1d\n\x19\x43ONFIG_TYPE_BYOK_BACKENDS\x10\x07\x12\x1a\n\x16\x43ONFIG_TYPE_GUARDRAILS\x10\x08\x12\x19\n\x15\x43ONFIG_TYPE_PROXY_URL\x10\t\x12\x15\n\x11\x43ONFIG_TYPE_PROXY\x10\n\x12 \n\x1c\x43ONFIG_TYPE_PROVIDER_SECRETS\x10\x0b\x12!\n\x1d\x43ONFIG_TYPE_DATAPLANE_UPGRADE\x10\x0c\x12\x1b\n\x17\x43ONFIG_TYPE_BYOK_SCOPED\x10\r*\x95\x02\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x45VENT_TYPE_NEW\x10\x01\x12\x15\n\x11\x45VENT_TYPE_UPDATE\x10\x02\x12\x16\n\x12\x45VENT_TYPE_UPGRADE\x10\x08\x12\x1d\n\x19\x45VENT_TYPE_UPGRADE_CANCEL\x10\t\x12\x1f\n\x1b\x45VENT_TYPE_UPGRADE_ROLLBACK\x10\n\x12\x15\n\x11\x45VENT_TYPE_DELETE\x10\x03\x12\x1a\n\x16\x45VENT_TYPE_UPDATE_BYOK\x10\x04\x12\x19\n\x15\x45VENT_TYPE_UPDATE_MCP\x10\x05\x12\x1b\n\x17\x45VENT_TYPE_UPDATE_OAUTH\x10\x06\x32\xa9#\n\x13\x43onfiguratorService\x12\xb8\x01\n\x10GetConfiguration\x12-.tars.configurator.v1.GetConfigurationRequest\x1a..tars.configurator.v1.GetConfigurationResponse\"E\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rConfiguration\x82\xd3\xe4\x93\x02\x1c\"\x17/configurator/v1/config:\x01*\x12\xad\x01\n\rTriggerUpdate\x12*.tars.configurator.v1.TriggerUpdateRequest\x1a+.tars.configurator.v1.TriggerUpdateResponse\"C\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rConfiguration\x82\xd3\xe4\x93\x02\x1d\"\x18/configurator/v1/trigger:\x01*\x12\xbc\x01\n\x12ListConfigurations\x12/.tars.configurator.v1.ListConfigurationsRequest\x1a\x30.tars.configurator.v1.ListConfigurationsResponse\"C\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rConfiguration\x82\xd3\xe4\x93\x02\x1a\x12\x18/configurator/v1/configs\x12\xb6\x01\n\x11ListPendingEvents\x12..tars.configurator.v1.ListPendingEventsRequest\x1a/.tars.configurator.v1.ListPendingEventsResponse\"@\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02!\x12\x1f/configurator/v1/pending-events\x12\xc9\x01\n\x12ReconcileWorkspace\x12/.tars.configurator.v1.ReconcileWorkspaceRequest\x1a\x30.tars.configurator.v1.ReconcileWorkspaceResponse\"P\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0eWorkspace Sync\x82\xd3\xe4\x93\x02)\"$/configurator/v1/reconcile-workspace:\x01*\x12\xc6\x01\n\x11\x46ullSyncWorkspace\x12..tars.configurator.v1.FullSyncWorkspaceRequest\x1a/.tars.configurator.v1.FullSyncWorkspaceResponse\"P\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0eWorkspace Sync\x82\xd3\xe4\x93\x02)\"$/configurator/v1/full-sync-workspace:\x01*\x12\xb9\x01\n\x10\x41\x63knowledgeEvent\x12-.tars.configurator.v1.AcknowledgeEventRequest\x1a..tars.configurator.v1.AcknowledgeEventResponse\"F\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02\'\"\"/configurator/v1/acknowledge-event:\x01*\x12\xb5\x01\n\x0fSetDataplaneURL\x12,.tars.configurator.v1.SetDataplaneURLRequest\x1a-.tars.configurator.v1.SetDataplaneURLResponse\"E\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\tDataplane\x82\xd3\xe4\x93\x02#\"\x1e/configurator/v1/dataplane-url:\x01*\x12\xd1\x01\n\x16UpsertMCPCatalogServer\x12\x33.tars.configurator.v1.UpsertMCPCatalogServerRequest\x1a\x34.tars.configurator.v1.UpsertMCPCatalogServerResponse\"L\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0bMCP Catalog\x82\xd3\xe4\x93\x02(\"#/configurator/v1/mcp-catalog/upsert:\x01*\x12\xc2\x01\n\x11ValidateDataplane\x12..tars.configurator.v1.ValidateDataplaneRequest\x1a/.tars.configurator.v1.ValidateDataplaneResponse\"L\x90\x02\x01\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\tDataplane\x82\xd3\xe4\x93\x02(\"#/configurator/v1/validate-dataplane:\x01*\x12\xad\x01\n\rCompleteEvent\x12*.tars.configurator.v1.CompleteEventRequest\x1a+.tars.configurator.v1.CompleteEventResponse\"C\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02$\"\x1f/configurator/v1/complete-event:\x01*\x12\xb5\x01\n\x0fListActiveUsers\x12,.tars.configurator.v1.ListActiveUsersRequest\x1a-.tars.configurator.v1.ListActiveUsersResponse\"E\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\nMonitoring\x82\xd3\xe4\x93\x02\x1f\x12\x1d/configurator/v1/active-users\x12\xc5\x01\n\x13ListActiveProviders\x12\x30.tars.configurator.v1.ListActiveProvidersRequest\x1a\x31.tars.configurator.v1.ListActiveProvidersResponse\"I\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\nMonitoring\x82\xd3\xe4\x93\x02#\x12!/configurator/v1/active-providers\x12\xbc\x01\n\x10SaveBYOKBackends\x12-.tars.configurator.v1.SaveBYOKBackendsRequest\x1a..tars.configurator.v1.SaveBYOKBackendsResponse\"I\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rBYOK Backends\x82\xd3\xe4\x93\x02#\"\x1e/configurator/v1/byok-backends:\x01*\x12\xc9\x01\n\x12\x44\x65leteBYOKBackends\x12/.tars.configurator.v1.DeleteBYOKBackendsRequest\x1a\x30.tars.configurator.v1.DeleteBYOKBackendsResponse\"P\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\rBYOK Backends\x82\xd3\xe4\x93\x02**(/configurator/v1/byok-backends/{user_id}\x12\xc2\x01\n\x0fRevokeUserToken\x12,.tars.configurator.v1.RevokeUserTokenRequest\x1a-.tars.configurator.v1.RevokeUserTokenResponse\"R\x8a\xb5\x18\x0b\n\x02\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x0bUser Tokens\x82\xd3\xe4\x93\x02.\")/configurator/v1/user-tokens/{jti}:revoke:\x01*\x12\xbe\x01\n\x13UpdateEventMetadata\x12\x30.tars.configurator.v1.UpdateEventMetadataRequest\x1a\x31.tars.configurator.v1.UpdateEventMetadataResponse\"B\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x06\x45vents\x82\xd3\xe4\x93\x02$\"\x1f/configurator/v1/event-metadata:\x01*\x12\x82\x02\n!SubmitDataplaneUpgradeCredentials\x12>.tars.configurator.v1.SubmitDataplaneUpgradeCredentialsRequest\x1a?.tars.configurator.v1.SubmitDataplaneUpgradeCredentialsResponse\"\\\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x33\"./configurator/v1/dataplane-upgrade-credentials:\x01*\x12\x80\x02\n\x1eGetDataplaneUpgradeCredentials\x12;.tars.configurator.v1.GetDataplaneUpgradeCredentialsRequest\x1a<.tars.configurator.v1.GetDataplaneUpgradeCredentialsResponse\"c\x90\x02\x01\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x37\"2/configurator/v1/dataplane-upgrade-credentials/get:\x01*\x12\xfd\x01\n\x1e\x41\x63kDataplaneUpgradeCredentials\x12;.tars.configurator.v1.AckDataplaneUpgradeCredentialsRequest\x1a<.tars.configurator.v1.AckDataplaneUpgradeCredentialsResponse\"`\x8a\xb5\x18\n\n\x01\x02\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x37\"2/configurator/v1/dataplane-upgrade-credentials/ack:\x01*\x12\xdc\x01\n\x16\x43\x61ncelDataplaneUpgrade\x12\x33.tars.configurator.v1.CancelDataplaneUpgradeRequest\x1a\x34.tars.configurator.v1.CancelDataplaneUpgradeResponse\"W\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02.\")/configurator/v1/dataplane-upgrade/cancel:\x01*\x12\xe4\x01\n\x18RollbackDataplaneUpgrade\x12\x35.tars.configurator.v1.RollbackDataplaneUpgradeRequest\x1a\x36.tars.configurator.v1.RollbackDataplaneUpgradeResponse\"Y\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x11\x44\x61taplane Upgrade\x82\xd3\xe4\x93\x02\x30\"+/configurator/v1/dataplane-upgrade/rollback:\x01*B\xe4\x01\n\x18\x63om.tars.configurator.v1B\x11\x43onfiguratorProtoP\x01ZCgithub.com/tetrateio/fraser/api/tars/configurator/v1;configuratorv1\xa2\x02\x03TCX\xaa\x02\x14Tars.Configurator.V1\xca\x02\x14Tars\\Configurator\\V1\xe2\x02 Tars\\Configurator\\V1\\GPBMetadata\xea\x02\x16Tars::Configurator::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.configurator.v1.configurator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.tars.configurator.v1B\021ConfiguratorProtoP\001ZCgithub.com/tetrateio/fraser/api/tars/configurator/v1;configuratorv1\242\002\003TCX\252\002\024Tars.Configurator.V1\312\002\024Tars\\Configurator\\V1\342\002 Tars\\Configurator\\V1\\GPBMetadata\352\002\026Tars::Configurator::V1'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetConfiguration']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetConfiguration']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rConfiguration\202\323\344\223\002\034\"\027/configurator/v1/config:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['TriggerUpdate']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['TriggerUpdate']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rConfiguration\202\323\344\223\002\035\"\030/configurator/v1/trigger:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListConfigurations']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListConfigurations']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rConfiguration\202\323\344\223\002\032\022\030/configurator/v1/configs'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListPendingEvents']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListPendingEvents']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002!\022\037/configurator/v1/pending-events'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ReconcileWorkspace']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ReconcileWorkspace']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\016Workspace Sync\202\323\344\223\002)\"$/configurator/v1/reconcile-workspace:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['FullSyncWorkspace']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['FullSyncWorkspace']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\016Workspace Sync\202\323\344\223\002)\"$/configurator/v1/full-sync-workspace:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AcknowledgeEvent']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AcknowledgeEvent']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002\'\"\"/configurator/v1/acknowledge-event:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SetDataplaneURL']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SetDataplaneURL']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\tDataplane\202\323\344\223\002#\"\036/configurator/v1/dataplane-url:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpsertMCPCatalogServer']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpsertMCPCatalogServer']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\013MCP Catalog\202\323\344\223\002(\"#/configurator/v1/mcp-catalog/upsert:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ValidateDataplane']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ValidateDataplane']._serialized_options = b'\220\002\001\212\265\030\n\n\001\002\022\005admin\252\265\030\tDataplane\202\323\344\223\002(\"#/configurator/v1/validate-dataplane:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CompleteEvent']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CompleteEvent']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002$\"\037/configurator/v1/complete-event:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveUsers']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveUsers']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\nMonitoring\202\323\344\223\002\037\022\035/configurator/v1/active-users'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveProviders']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['ListActiveProviders']._serialized_options = b'\220\002\001\212\265\030\013\n\002\001\002\022\005admin\252\265\030\nMonitoring\202\323\344\223\002#\022!/configurator/v1/active-providers'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SaveBYOKBackends']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SaveBYOKBackends']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rBYOK Backends\202\323\344\223\002#\"\036/configurator/v1/byok-backends:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['DeleteBYOKBackends']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['DeleteBYOKBackends']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\rBYOK Backends\202\323\344\223\002**(/configurator/v1/byok-backends/{user_id}'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RevokeUserToken']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RevokeUserToken']._serialized_options = b'\212\265\030\013\n\002\001\002\022\005admin\252\265\030\013User Tokens\202\323\344\223\002.\")/configurator/v1/user-tokens/{jti}:revoke:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpdateEventMetadata']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['UpdateEventMetadata']._serialized_options = b'\212\265\030\n\n\001\002\022\005admin\252\265\030\006Events\202\323\344\223\002$\"\037/configurator/v1/event-metadata:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SubmitDataplaneUpgradeCredentials']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['SubmitDataplaneUpgradeCredentials']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0023\"./configurator/v1/dataplane-upgrade-credentials:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetDataplaneUpgradeCredentials']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['GetDataplaneUpgradeCredentials']._serialized_options = b'\220\002\001\212\265\030\n\n\001\002\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0027\"2/configurator/v1/dataplane-upgrade-credentials/get:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AckDataplaneUpgradeCredentials']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['AckDataplaneUpgradeCredentials']._serialized_options = b'\212\265\030\n\n\001\002\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0027\"2/configurator/v1/dataplane-upgrade-credentials/ack:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CancelDataplaneUpgrade']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['CancelDataplaneUpgrade']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\002.\")/configurator/v1/dataplane-upgrade/cancel:\001*'
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RollbackDataplaneUpgrade']._loaded_options = None
  _globals['_CONFIGURATORSERVICE'].methods_by_name['RollbackDataplaneUpgrade']._serialized_options = b'\212\265\030\n\n\001\001\022\005admin\252\265\030\021Dataplane Upgrade\202\323\344\223\0020\"+/configurator/v1/dataplane-upgrade/rollback:\001*'
  _globals['_CONFIGTYPE']._serialized_start=7308
  _globals['_CONFIGTYPE']._serialized_end=7726
  _globals['_EVENTTYPE']._serialized_start=7729
  _globals['_EVENTTYPE']._serialized_end=8006
  _globals['_GETCONFIGURATIONREQUEST']._serialized_start=186
  _globals['_GETCONFIGURATIONREQUEST']._serialized_end=276
  _globals['_USERCONFIGQUERY']._serialized_start=279
  _globals['_USERCONFIGQUERY']._serialized_end=452
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_start=454
  _globals['_GETCONFIGURATIONRESPONSE']._serialized_end=557
  _globals['_TRIGGERUPDATEREQUEST']._serialized_start=560
  _globals['_TRIGGERUPDATEREQUEST']._serialized_end=863
  _globals['_TRIGGERMETADATA']._serialized_start=865
  _globals['_TRIGGERMETADATA']._serialized_end=974
  _globals['_DATAPLANEUPGRADETRIGGER']._serialized_start=977
  _globals['_DATAPLANEUPGRADETRIGGER']._serialized_end=1235
  _globals['_TRIGGERUPDATERESPONSE']._serialized_start=1238
  _globals['_TRIGGERUPDATERESPONSE']._serialized_end=1389
  _globals['_LISTCONFIGURATIONSREQUEST']._serialized_start=1392
  _globals['_LISTCONFIGURATIONSREQUEST']._serialized_end=1571
  _globals['_LISTCONFIGURATIONSRESPONSE']._serialized_start=1574
  _globals['_LISTCONFIGURATIONSRESPONSE']._serialized_end=1719
  _globals['_LISTPENDINGEVENTSREQUEST']._serialized_start=1722
  _globals['_LISTPENDINGEVENTSREQUEST']._serialized_end=1852
  _globals['_DOCTORRUNTIMESTATUS']._serialized_start=1855
  _globals['_DOCTORRUNTIMESTATUS']._serialized_end=2127
  _globals['_LISTPENDINGEVENTSRESPONSE']._serialized_start=2129
  _globals['_LISTPENDINGEVENTSRESPONSE']._serialized_end=2222
  _globals['_RECONCILEWORKSPACEREQUEST']._serialized_start=2224
  _globals['_RECONCILEWORKSPACEREQUEST']._serialized_end=2251
  _globals['_RECONCILEWORKSPACERESPONSE']._serialized_start=2254
  _globals['_RECONCILEWORKSPACERESPONSE']._serialized_end=2464
  _globals['_FULLSYNCWORKSPACEREQUEST']._serialized_start=2466
  _globals['_FULLSYNCWORKSPACEREQUEST']._serialized_end=2492
  _globals['_FULLSYNCWORKSPACERESPONSE']._serialized_start=2495
  _globals['_FULLSYNCWORKSPACERESPONSE']._serialized_end=2663
  _globals['_CONFIGURATIONEVENT']._serialized_start=2666
  _globals['_CONFIGURATIONEVENT']._serialized_end=3099
  _globals['_ACKNOWLEDGEEVENTREQUEST']._serialized_start=3101
  _globals['_ACKNOWLEDGEEVENTREQUEST']._serialized_end=3182
  _globals['_ACKNOWLEDGEEVENTRESPONSE']._serialized_start=3184
  _globals['_ACKNOWLEDGEEVENTRESPONSE']._serialized_end=3236
  _globals['_COMPLETEEVENTREQUEST']._serialized_start=3238
  _globals['_COMPLETEEVENTREQUEST']._serialized_end=3350
  _globals['_COMPLETEEVENTRESPONSE']._serialized_start=3352
  _globals['_COMPLETEEVENTRESPONSE']._serialized_end=3401
  _globals['_LISTACTIVEUSERSREQUEST']._serialized_start=3403
  _globals['_LISTACTIVEUSERSREQUEST']._serialized_end=3449
  _globals['_LISTACTIVEUSERSRESPONSE']._serialized_start=3451
  _globals['_LISTACTIVEUSERSRESPONSE']._serialized_end=3503
  _globals['_CONFIGURATION']._serialized_start=3506
  _globals['_CONFIGURATION']._serialized_end=3829
  _globals['_PROVIDERBACKEND']._serialized_start=3832
  _globals['_PROVIDERBACKEND']._serialized_end=4068
  _globals['_SAVEBYOKBACKENDSREQUEST']._serialized_start=4071
  _globals['_SAVEBYOKBACKENDSREQUEST']._serialized_end=4221
  _globals['_SAVEBYOKBACKENDSRESPONSE']._serialized_start=4223
  _globals['_SAVEBYOKBACKENDSRESPONSE']._serialized_end=4350
  _globals['_DELETEBYOKBACKENDSREQUEST']._serialized_start=4352
  _globals['_DELETEBYOKBACKENDSREQUEST']._serialized_end=4404
  _globals['_DELETEBYOKBACKENDSRESPONSE']._serialized_start=4406
  _globals['_DELETEBYOKBACKENDSRESPONSE']._serialized_end=4460
  _globals['_REVOKEUSERTOKENREQUEST']._serialized_start=4462
  _globals['_REVOKEUSERTOKENREQUEST']._serialized_end=4569
  _globals['_REVOKEUSERTOKENRESPONSE']._serialized_start=4571
  _globals['_REVOKEUSERTOKENRESPONSE']._serialized_end=4681
  _globals['_PROVIDER']._serialized_start=4684
  _globals['_PROVIDER']._serialized_end=4989
  _globals['_LISTACTIVEPROVIDERSREQUEST']._serialized_start=4991
  _globals['_LISTACTIVEPROVIDERSREQUEST']._serialized_end=5019
  _globals['_LISTACTIVEPROVIDERSRESPONSE']._serialized_start=5021
  _globals['_LISTACTIVEPROVIDERSRESPONSE']._serialized_end=5112
  _globals['_SETDATAPLANEURLREQUEST']._serialized_start=5114
  _globals['_SETDATAPLANEURLREQUEST']._serialized_end=5230
  _globals['_SETDATAPLANEURLRESPONSE']._serialized_start=5232
  _globals['_SETDATAPLANEURLRESPONSE']._serialized_end=5257
  _globals['_UPSERTMCPCATALOGSERVERREQUEST']._serialized_start=5260
  _globals['_UPSERTMCPCATALOGSERVERREQUEST']._serialized_end=5591
  _globals['_UPSERTMCPCATALOGSERVERRESPONSE']._serialized_start=5593
  _globals['_UPSERTMCPCATALOGSERVERRESPONSE']._serialized_end=5651
  _globals['_VALIDATEDATAPLANEREQUEST']._serialized_start=5653
  _globals['_VALIDATEDATAPLANEREQUEST']._serialized_end=5679
  _globals['_VALIDATEDATAPLANERESPONSE']._serialized_start=5681
  _globals['_VALIDATEDATAPLANERESPONSE']._serialized_end=5805
  _globals['_GATEKEEPERPUBLICKEY']._serialized_start=5807
  _globals['_GATEKEEPERPUBLICKEY']._serialized_end=5920
  _globals['_UPDATEEVENTMETADATAREQUEST']._serialized_start=5922
  _globals['_UPDATEEVENTMETADATAREQUEST']._serialized_end=6005
  _globals['_UPDATEEVENTMETADATARESPONSE']._serialized_start=6007
  _globals['_UPDATEEVENTMETADATARESPONSE']._serialized_end=6062
  _globals['_CANCELDATAPLANEUPGRADEREQUEST']._serialized_start=6064
  _globals['_CANCELDATAPLANEUPGRADEREQUEST']._serialized_end=6137
  _globals['_CANCELDATAPLANEUPGRADERESPONSE']._serialized_start=6139
  _globals['_CANCELDATAPLANEUPGRADERESPONSE']._serialized_end=6197
  _globals['_ROLLBACKDATAPLANEUPGRADEREQUEST']._serialized_start=6199
  _globals['_ROLLBACKDATAPLANEUPGRADEREQUEST']._serialized_end=6274
  _globals['_ROLLBACKDATAPLANEUPGRADERESPONSE']._serialized_start=6276
  _globals['_ROLLBACKDATAPLANEUPGRADERESPONSE']._serialized_end=6380
  _globals['_DATAPLANEUPGRADECREDENTIAL']._serialized_start=6383
  _globals['_DATAPLANEUPGRADECREDENTIAL']._serialized_end=6515
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_start=6518
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_end=6732
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_start=6734
  _globals['_SUBMITDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_end=6842
  _globals['_GETDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_start=6844
  _globals['_GETDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_end=6925
  _globals['_GETDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_start=6928
  _globals['_GETDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_end=7124
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_start=7126
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSREQUEST']._serialized_end=7237
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_start=7239
  _globals['_ACKDATAPLANEUPGRADECREDENTIALSRESPONSE']._serialized_end=7305
  _globals['_CONFIGURATORSERVICE']._serialized_start=8009
  _globals['_CONFIGURATORSERVICE']._serialized_end=12530
# @@protoc_insertion_point(module_scope)



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.common.v1 import types_pb2 as _types_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Provider(_message.Message):
    __slots__ = ("id", "name", "display_name", "base_url", "supported_auth_schemes", "credential_suffix", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    BASE_URL_FIELD_NUMBER: _ClassVar[int]
    SUPPORTED_AUTH_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    CREDENTIAL_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    display_name: str
    base_url: str
    supported_auth_schemes: _containers.RepeatedScalarFieldContainer[str]
    credential_suffix: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., display_name: _Optional[str] = ..., base_url: _Optional[str] = ..., supported_auth_schemes: _Optional[_Iterable[str]] = ..., credential_suffix: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Pricing(_message.Message):
    __slots__ = ("input_per_million", "output_per_million", "cache_read_per_million", "max_cost_per_request")
    INPUT_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    MAX_COST_PER_REQUEST_FIELD_NUMBER: _ClassVar[int]
    input_per_million: str
    output_per_million: str
    cache_read_per_million: str
    max_cost_per_request: str
    def __init__(self, input_per_million: _Optional[str] = ..., output_per_million: _Optional[str] = ..., cache_read_per_million: _Optional[str] = ..., max_cost_per_request: _Optional[str] = ...) -> None: ...

class Model(_message.Message):
    __slots__ = ("id", "provider_id", "name", "upstream_model", "pricing", "max_context_tokens", "capabilities", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    UPSTREAM_MODEL_FIELD_NUMBER: _ClassVar[int]
    PRICING_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEXT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    provider_id: str
    name: str
    upstream_model: str
    pricing: Pricing
    max_context_tokens: int
    capabilities: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., provider_id: _Optional[str] = ..., name: _Optional[str] = ..., upstream_model: _Optional[str] = ..., pricing: _Optional[_Union[Pricing, _Mapping]] = ..., max_context_tokens: _Optional[int] = ..., capabilities: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ListProvidersRequest(_message.Message):
    __slots__ = ("page",)
    PAGE_FIELD_NUMBER: _ClassVar[int]
    page: _types_pb2.PageRequest
    def __init__(self, page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListProvidersResponse(_message.Message):
    __slots__ = ("providers", "page")
    PROVIDERS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    providers: _containers.RepeatedCompositeFieldContainer[Provider]
    page: _types_pb2.PageResponse
    def __init__(self, providers: _Optional[_Iterable[_Union[Provider, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class GetProviderRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetProviderResponse(_message.Message):
    __slots__ = ("provider",)
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: Provider
    def __init__(self, provider: _Optional[_Union[Provider, _Mapping]] = ...) -> None: ...

class ListModelsRequest(_message.Message):
    __slots__ = ("provider_id", "page")
    PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    provider_id: str
    page: _types_pb2.PageRequest
    def __init__(self, provider_id: _Optional[str] = ..., page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListModelsResponse(_message.Message):
    __slots__ = ("models", "page")
    MODELS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    models: _containers.RepeatedCompositeFieldContainer[Model]
    page: _types_pb2.PageResponse
    def __init__(self, models: _Optional[_Iterable[_Union[Model, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class GetModelRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetModelResponse(_message.Message):
    __slots__ = ("model",)
    MODEL_FIELD_NUMBER: _ClassVar[int]
    model: Model
    def __init__(self, model: _Optional[_Union[Model, _Mapping]] = ...) -> None: ...

class ProjectModelEntry(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "model_id", "model", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    model_id: str
    model: Model
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_id: _Optional[str] = ..., model: _Optional[_Union[Model, _Mapping]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class UpsertProviderRequest(_message.Message):
    __slots__ = ("id", "display_name", "base_url", "supported_auth_schemes")
    ID_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    BASE_URL_FIELD_NUMBER: _ClassVar[int]
    SUPPORTED_AUTH_SCHEMES_FIELD_NUMBER: _ClassVar[int]
    id: str
    display_name: str
    base_url: str
    supported_auth_schemes: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., display_name: _Optional[str] = ..., base_url: _Optional[str] = ..., supported_auth_schemes: _Optional[_Iterable[str]] = ...) -> None: ...

class UpsertModelRequest(_message.Message):
    __slots__ = ("provider_id", "name", "upstream_model", "input_per_million", "output_per_million", "cache_read_per_million", "max_cost_per_request", "max_context_tokens", "capabilities")
    PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    UPSTREAM_MODEL_FIELD_NUMBER: _ClassVar[int]
    INPUT_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    CACHE_READ_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    MAX_COST_PER_REQUEST_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEXT_TOKENS_FIELD_NUMBER: _ClassVar[int]
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    provider_id: str
    name: str
    upstream_model: str
    input_per_million: str
    output_per_million: str
    cache_read_per_million: str
    max_cost_per_request: str
    max_context_tokens: int
    capabilities: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, provider_id: _Optional[str] = ..., name: _Optional[str] = ..., upstream_model: _Optional[str] = ..., input_per_million: _Optional[str] = ..., output_per_million: _Optional[str] = ..., cache_read_per_million: _Optional[str] = ..., max_cost_per_request: _Optional[str] = ..., max_context_tokens: _Optional[int] = ..., capabilities: _Optional[_Iterable[str]] = ...) -> None: ...

class SetProviderCredentialRequest(_message.Message):
    __slots__ = ("id", "credential")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREDENTIAL_FIELD_NUMBER: _ClassVar[int]
    id: str
    credential: str
    def __init__(self, id: _Optional[str] = ..., credential: _Optional[str] = ...) -> None: ...

class DeleteProviderRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteModelRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class AssignModelToProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "model_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    model_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_id: _Optional[str] = ...) -> None: ...

class AssignModelToProjectResponse(_message.Message):
    __slots__ = ("entry",)
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: ProjectModelEntry
    def __init__(self, entry: _Optional[_Union[ProjectModelEntry, _Mapping]] = ...) -> None: ...

class ListProjectModelsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListProjectModelsResponse(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[ProjectModelEntry]
    def __init__(self, entries: _Optional[_Iterable[_Union[ProjectModelEntry, _Mapping]]] = ...) -> None: ...

class UnassignModelFromProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "model_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    model_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_id: _Optional[str] = ...) -> None: ...

class UnassignModelFromProjectResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...



from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.common.v1 import types_pb2 as _types_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from tars.identity.v1 import api_key_pb2 as _api_key_pb2
from tars.identity.v1 import identity_pb2 as _identity_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LoginRequest(_message.Message):
    __slots__ = ("issuer", "redirect_uri", "code_challenge", "code_challenge_method")
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_METHOD_FIELD_NUMBER: _ClassVar[int]
    issuer: str
    redirect_uri: str
    code_challenge: str
    code_challenge_method: str
    def __init__(self, issuer: _Optional[str] = ..., redirect_uri: _Optional[str] = ..., code_challenge: _Optional[str] = ..., code_challenge_method: _Optional[str] = ...) -> None: ...

class LoginResponse(_message.Message):
    __slots__ = ("authorization_url", "state")
    AUTHORIZATION_URL_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    authorization_url: str
    state: str
    def __init__(self, authorization_url: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class LogoutRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class LogoutResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetMeRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetMeResponse(_message.Message):
    __slots__ = ("identity",)
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    identity: _identity_pb2.Identity
    def __init__(self, identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ...) -> None: ...

class IssueMyKeyRequest(_message.Message):
    __slots__ = ("name", "type", "idempotency_key")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    IDEMPOTENCY_KEY_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: _api_key_pb2.ApiKeyType
    idempotency_key: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[_api_key_pb2.ApiKeyType, str]] = ..., idempotency_key: _Optional[str] = ...) -> None: ...

class IssueMyKeyResponse(_message.Message):
    __slots__ = ("key", "secret")
    KEY_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    key: _api_key_pb2.ApiKey
    secret: str
    def __init__(self, key: _Optional[_Union[_api_key_pb2.ApiKey, _Mapping]] = ..., secret: _Optional[str] = ...) -> None: ...

class ListMyKeysRequest(_message.Message):
    __slots__ = ("page",)
    PAGE_FIELD_NUMBER: _ClassVar[int]
    page: _types_pb2.PageRequest
    def __init__(self, page: _Optional[_Union[_types_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class ListMyKeysResponse(_message.Message):
    __slots__ = ("keys", "page")
    KEYS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    keys: _containers.RepeatedCompositeFieldContainer[_api_key_pb2.ApiKey]
    page: _types_pb2.PageResponse
    def __init__(self, keys: _Optional[_Iterable[_Union[_api_key_pb2.ApiKey, _Mapping]]] = ..., page: _Optional[_Union[_types_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class RevokeMyKeyRequest(_message.Message):
    __slots__ = ("key_id",)
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    def __init__(self, key_id: _Optional[str] = ...) -> None: ...

class RevokeMyKeyResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ResolveApiKeyRequest(_message.Message):
    __slots__ = ("key",)
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class ResolveApiKeyResponse(_message.Message):
    __slots__ = ("identity", "key")
    IDENTITY_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    identity: _identity_pb2.Identity
    key: _api_key_pb2.ApiKey
    def __init__(self, identity: _Optional[_Union[_identity_pb2.Identity, _Mapping]] = ..., key: _Optional[_Union[_api_key_pb2.ApiKey, _Mapping]] = ...) -> None: ...



"""Unit tests for AgentrouterError reason decoding.

Builds Connect-JSON error envelopes the way valet emits them (a
``google.rpc.ErrorInfo`` detail with a base64 binary ``value`` and an
optional JSON ``debug``) and asserts the reason is surfaced on the error.
"""

from __future__ import annotations

import base64
import json

from agentrouter_sdk.errors import (
    AgentrouterError,
    _read_proto_field1_string,
    _reason_from_envelope,
    from_http_response,
)


def _varint(n: int) -> bytes:
    out = bytearray()
    while True:
        b = n & 0x7F
        n >>= 7
        if n:
            out.append(b | 0x80)
        else:
            out.append(b)
            return bytes(out)


def _field_string(field_no: int, s: str) -> bytes:
    data = s.encode()
    return _varint((field_no << 3) | 2) + _varint(len(data)) + data


def _error_info_bytes(reason: str, domain: str = "tetrate.ai") -> bytes:
    """Encode a google.rpc.ErrorInfo (reason=field1, domain=field2)."""
    return _field_string(1, reason) + _field_string(2, domain)


def _b64(raw: bytes) -> str:
    return base64.b64encode(raw).decode()


# -- low-level field reader -------------------------------------------


def test_read_field1_skips_later_fields():
    raw = _error_info_bytes("MODEL_NOT_FOUND")
    assert _read_proto_field1_string(raw) == "MODEL_NOT_FOUND"


def test_read_field1_empty_when_field1_absent():
    # Only field 2 (domain) present.
    raw = _field_string(2, "tetrate.ai")
    assert _read_proto_field1_string(raw) == ""


# -- envelope extraction ----------------------------------------------


def test_reason_prefers_debug_json():
    raw = _error_info_bytes("MODEL_NOT_FOUND")
    env = {
        "code": "not_found",
        "message": "model foo not found",
        "details": [
            {
                "type": "google.rpc.ErrorInfo",
                "value": _b64(raw),
                "debug": {"reason": "MODEL_NOT_FOUND", "domain": "tetrate.ai"},
            }
        ],
    }
    assert _reason_from_envelope(env) == "MODEL_NOT_FOUND"


def test_reason_falls_back_to_binary_value_without_debug():
    env = {
        "code": "permission_denied",
        "message": "denied",
        "details": [
            {
                "type": "google.rpc.ErrorInfo",
                "value": _b64(_error_info_bytes("CROSS_TENANT_DENIED")),
            }
        ],
    }
    assert _reason_from_envelope(env) == "CROSS_TENANT_DENIED"


def test_reason_empty_without_error_info_detail():
    assert _reason_from_envelope({"code": "internal", "message": "x"}) == ""
    assert (
        _reason_from_envelope(
            {"details": [{"type": "google.rpc.BadRequest", "value": "AA=="}]}
        )
        == ""
    )


# -- full from_http_response round-trip --------------------------------


def test_from_http_response_surfaces_reason():
    raw = _error_info_bytes("MODEL_NOT_FOUND")
    body = json.dumps(
        {
            "code": "not_found",
            "message": "model foo not found",
            "details": [
                {
                    "type": "google.rpc.ErrorInfo",
                    "value": _b64(raw),
                    "debug": {"reason": "MODEL_NOT_FOUND"},
                }
            ],
        }
    ).encode()
    err = from_http_response(404, body)
    assert isinstance(err, AgentrouterError)
    assert err.code == "not_found"
    assert err.reason == "MODEL_NOT_FOUND"
    assert err.message == "model foo not found"
    assert err.status == 404


def test_from_http_response_empty_reason_when_no_detail():
    body = json.dumps({"code": "unauthenticated", "message": "no"}).encode()
    err = from_http_response(401, body)
    assert err.reason == ""
    assert err.code == "unauthenticated"


def test_constructor_default_reason_is_empty():
    assert AgentrouterError("internal", "boom").reason == ""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/identity/v1/api_key.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/identity/v1/api_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etars/identity/v1/api_key.proto\x12\x10tars.identity.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x89\x04\n\x06\x41piKey\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0bidentity_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nidentityId\x12$\n\x0b\x63ustomer_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12\x1b\n\x06prefix\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x06prefix\x12\x38\n\x05state\x18\x06 \x01(\x0e\x32\x1d.tars.identity.v1.ApiKeyStateB\x03\xe0\x41\x03R\x05state\x12\x35\n\x04type\x18\t \x01(\x0e\x32\x1c.tars.identity.v1.ApiKeyTypeB\x03\xe0\x41\x03R\x04type\x12\x39\n\nexpires_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12\x41\n\x0clast_used_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\nlastUsedAt\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nrevoked_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\trevokedAt\"\xa6\x02\n\x07Session\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0bidentity_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nidentityId\x12<\n\tissued_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x08issuedAt\x12>\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\texpiresAt\x12)\n\x0estep_up_active\x18\x05 \x01(\x08\x42\x03\xe0\x41\x03R\x0cstepUpActive\x12\"\n\nuser_agent\x18\x06 \x01(\tB\x03\xe0\x41\x03R\tuserAgent\x12\x13\n\x02ip\x18\x07 \x01(\tB\x03\xe0\x41\x03R\x02ip\"\xed\x01\n\x03Jwk\x12\x15\n\x03kid\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03kid\x12$\n\x0bidentity_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\nidentityId\x12)\n\x0epublic_key_pem\x18\x03 \x01(\x0c\x42\x03\xe0\x41\x02R\x0cpublicKeyPem\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\ndeleted_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tdeletedAt*a\n\x0b\x41piKeyState\x12\x1d\n\x19\x41PI_KEY_STATE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41PI_KEY_STATE_ACTIVE\x10\x01\x12\x19\n\x15\x41PI_KEY_STATE_REVOKED\x10\x02*`\n\nApiKeyType\x12\x1c\n\x18\x41PI_KEY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41PI_KEY_TYPE_PROMPT\x10\x01\x12\x1b\n\x17\x41PI_KEY_TYPE_MANAGEMENT\x10\x02\x42\xc2\x01\n\x14\x63om.tars.identity.v1B\x0b\x41piKeyProtoP\x01Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Identity.V1\xca\x02\x10Tars\\Identity\\V1\xe2\x02\x1cTars\\Identity\\V1\\GPBMetadata\xea\x02\x12Tars::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.identity.v1.api_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.identity.v1B\013ApiKeyProtoP\001Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\242\002\003TIX\252\002\020Tars.Identity.V1\312\002\020Tars\\Identity\\V1\342\002\034Tars\\Identity\\V1\\GPBMetadata\352\002\022Tars::Identity::V1'
  _globals['_APIKEY'].fields_by_name['id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['identity_id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['identity_id']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['customer_id']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['prefix']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['prefix']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['state']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['type']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['type']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['last_used_at']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['last_used_at']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['created_at']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_APIKEY'].fields_by_name['revoked_at']._loaded_options = None
  _globals['_APIKEY'].fields_by_name['revoked_at']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['id']._loaded_options = None
  _globals['_SESSION'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['identity_id']._loaded_options = None
  _globals['_SESSION'].fields_by_name['identity_id']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['issued_at']._loaded_options = None
  _globals['_SESSION'].fields_by_name['issued_at']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['expires_at']._loaded_options = None
  _globals['_SESSION'].fields_by_name['expires_at']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['step_up_active']._loaded_options = None
  _globals['_SESSION'].fields_by_name['step_up_active']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['user_agent']._loaded_options = None
  _globals['_SESSION'].fields_by_name['user_agent']._serialized_options = b'\340A\003'
  _globals['_SESSION'].fields_by_name['ip']._loaded_options = None
  _globals['_SESSION'].fields_by_name['ip']._serialized_options = b'\340A\003'
  _globals['_JWK'].fields_by_name['kid']._loaded_options = None
  _globals['_JWK'].fields_by_name['kid']._serialized_options = b'\340A\002'
  _globals['_JWK'].fields_by_name['identity_id']._loaded_options = None
  _globals['_JWK'].fields_by_name['identity_id']._serialized_options = b'\340A\003'
  _globals['_JWK'].fields_by_name['public_key_pem']._loaded_options = None
  _globals['_JWK'].fields_by_name['public_key_pem']._serialized_options = b'\340A\002'
  _globals['_JWK'].fields_by_name['created_at']._loaded_options = None
  _globals['_JWK'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_JWK'].fields_by_name['deleted_at']._loaded_options = None
  _globals['_JWK'].fields_by_name['deleted_at']._serialized_options = b'\340A\003'
  _globals['_APIKEYSTATE']._serialized_start=1179
  _globals['_APIKEYSTATE']._serialized_end=1276
  _globals['_APIKEYTYPE']._serialized_start=1278
  _globals['_APIKEYTYPE']._serialized_end=1374
  _globals['_APIKEY']._serialized_start=119
  _globals['_APIKEY']._serialized_end=640
  _globals['_SESSION']._serialized_start=643
  _globals['_SESSION']._serialized_end=937
  _globals['_JWK']._serialized_start=940
  _globals['_JWK']._serialized_end=1177
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/sdk/v1/sdk.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/sdk/v1/sdk.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15tars/sdk/v1/sdk.proto\x12\x0btars.sdk.v1\x1a google/protobuf/descriptor.proto:9\n\x06handle\x12\x1f.google.protobuf.ServiceOptions\x18\xd6\x86\x03 \x01(\tR\x06handle:8\n\x06method\x12\x1e.google.protobuf.MethodOptions\x18\xd6\x86\x03 \x01(\tR\x06methodB\x9c\x01\n\x0f\x63om.tars.sdk.v1B\x08SdkProtoP\x01Z1github.com/tetrateio/fraser/api/tars/sdk/v1;sdkv1\xa2\x02\x03TSX\xaa\x02\x0bTars.Sdk.V1\xca\x02\x0bTars\\Sdk\\V1\xe2\x02\x17Tars\\Sdk\\V1\\GPBMetadata\xea\x02\rTars::Sdk::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.sdk.v1.sdk_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.tars.sdk.v1B\010SdkProtoP\001Z1github.com/tetrateio/fraser/api/tars/sdk/v1;sdkv1\242\002\003TSX\252\002\013Tars.Sdk.V1\312\002\013Tars\\Sdk\\V1\342\002\027Tars\\Sdk\\V1\\GPBMetadata\352\002\rTars::Sdk::V1'
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
COMMAND_FIELD_NUMBER: _ClassVar[int]
command: _descriptor.FieldDescriptor
FIELD_FIELD_NUMBER: _ClassVar[int]
field: _descriptor.FieldDescriptor

class Command(_message.Message):
    __slots__ = ("name", "aliases", "primary_flag", "hidden", "path")
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALIASES_FIELD_NUMBER: _ClassVar[int]
    PRIMARY_FLAG_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    name: str
    aliases: _containers.RepeatedScalarFieldContainer[str]
    primary_flag: str
    hidden: bool
    path: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., aliases: _Optional[_Iterable[str]] = ..., primary_flag: _Optional[str] = ..., hidden: _Optional[bool] = ..., path: _Optional[_Iterable[str]] = ...) -> None: ...

class Field(_message.Message):
    __slots__ = ("flag", "hidden")
    FLAG_FIELD_NUMBER: _ClassVar[int]
    HIDDEN_FIELD_NUMBER: _ClassVar[int]
    flag: str
    hidden: bool
    def __init__(self, flag: _Optional[str] = ..., hidden: _Optional[bool] = ...) -> None: ...



"""Connect-JSON transport for the agentrouter Python SDK.

Implements a minimal Connect-RPC client over JSON using :mod:`httpx`. The
transport takes a request protobuf message, serializes it to JSON via
``json_format``, POSTs to ``<base>/<package>.<Service>/<Method>``, and
deserializes the response into the supplied response message type.
"""

from __future__ import annotations

import time
from dataclasses import dataclass, field
from typing import Callable, TypeVar

import httpx
from google.protobuf import json_format
from google.protobuf.message import Message

from .errors import AgentrouterError, RETRYABLE, UNAVAILABLE, from_http_response


T = TypeVar("T", bound=Message)


@dataclass
class RetryPolicy:
    """Retry policy controlling transient-failure recovery."""

    max_attempts: int = 3
    initial_backoff_s: float = 0.1
    max_backoff_s: float = 5.0
    total_budget_s: float = 90.0
    jitter_fraction: float = 0.2


@dataclass
class TransportConfig:
    """Resolved transport configuration shared across service handles."""

    base_url: str
    headers: dict[str, str] = field(default_factory=dict)
    timeout_s: float = 30.0
    retry: RetryPolicy = field(default_factory=RetryPolicy)
    httpx_client_factory: Callable[[], httpx.Client] | None = None


class Transport:
    """Connect-JSON over HTTP transport.

    One transport per service endpoint URL is fine; the SDK shares a single
    underlying :class:`httpx.Client` across all transports when possible.
    """

    def __init__(self, cfg: TransportConfig, client: httpx.Client):
        self._cfg = cfg
        self._client = client

    def unary(
        self,
        service_fqn: str,
        method: str,
        request: Message,
        response_cls: type[T],
    ) -> T:
        """Call ``<base>/<service_fqn>/<method>`` and decode into response_cls.

        ``service_fqn`` is the fully-qualified proto service name (e.g.
        ``tars.catalog.v1.CatalogService``).
        """
        path = f"/{service_fqn}/{method}"
        url = f"{self._cfg.base_url}{path}"
        # MessageToJson defaults: camelCase field names, omit defaults, sorted.
        # Use the no-kwargs form so the SDK works across protobuf 5.26+ where
        # individual flag names have been renamed (e.g. including_default_value_fields ->
        # always_print_fields_with_no_presence in newer point releases).
        body = json_format.MessageToJson(request)
        headers = {
            "Content-Type": "application/json",
            "Connect-Protocol-Version": "1",
        }
        headers.update(self._cfg.headers)

        attempts = max(1, self._cfg.retry.max_attempts)
        backoff = self._cfg.retry.initial_backoff_s
        deadline = time.monotonic() + self._cfg.retry.total_budget_s if self._cfg.retry.total_budget_s > 0 else float("inf")

        last_err: AgentrouterError | None = None
        for attempt in range(attempts):
            try:
                resp = self._client.post(url, content=body, headers=headers, timeout=self._cfg.timeout_s)
            except httpx.TimeoutException as e:
                last_err = AgentrouterError("deadline_exceeded", str(e))
            except httpx.TransportError as e:
                last_err = AgentrouterError(UNAVAILABLE, str(e))
            else:
                if resp.status_code == 200:
                    out = response_cls()
                    if resp.content:
                        json_format.Parse(resp.content, out, ignore_unknown_fields=True)
                    return out
                last_err = from_http_response(resp.status_code, resp.content)

            if last_err is not None and last_err.code in RETRYABLE and attempt < attempts - 1:
                wait = min(backoff, self._cfg.retry.max_backoff_s)
                if time.monotonic() + wait < deadline:
                    time.sleep(wait)
                    backoff *= 2
                    continue
            assert last_err is not None
            raise last_err
        assert last_err is not None
        raise last_err

    def close(self) -> None:
        # The SDK owns the httpx.Client and closes it from Client.close().
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/identity/v1/identity_service.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/identity/v1/identity_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2
from tars.identity.v1 import api_key_pb2 as tars_dot_identity_dot_v1_dot_api__key__pb2
from tars.identity.v1 import identity_pb2 as tars_dot_identity_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'tars/identity/v1/identity_service.proto\x12\x10tars.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\x1a\x1etars/identity/v1/api_key.proto\x1a\x1ftars/identity/v1/identity.proto\"\xb3\x01\n\x0cLoginRequest\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12&\n\x0credirect_uri\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0bredirectUri\x12*\n\x0e\x63ode_challenge\x18\x03 \x01(\tB\x03\xe0\x41\x02R\rcodeChallenge\x12\x37\n\x15\x63ode_challenge_method\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x13\x63odeChallengeMethod\"\\\n\rLoginResponse\x12\x30\n\x11\x61uthorization_url\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x10\x61uthorizationUrl\x12\x19\n\x05state\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x05state\"\x0f\n\rLogoutRequest\"\x10\n\x0eLogoutResponse\"\x0e\n\x0cGetMeRequest\"G\n\rGetMeResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32\x1a.tars.identity.v1.IdentityR\x08identity\"\x87\x01\n\x11IssueMyKeyRequest\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\x1c.tars.identity.v1.ApiKeyTypeR\x04type\x12\'\n\x0fidempotency_key\x18\x63 \x01(\tR\x0eidempotencyKey\"]\n\x12IssueMyKeyResponse\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x18.tars.identity.v1.ApiKeyR\x03key\x12\x1b\n\x06secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x06secret\"D\n\x11ListMyKeysRequest\x12/\n\x04page\x18\x01 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"t\n\x12ListMyKeysResponse\x12,\n\x04keys\x18\x01 \x03(\x0b\x32\x18.tars.identity.v1.ApiKeyR\x04keys\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"0\n\x12RevokeMyKeyRequest\x12\x1a\n\x06key_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05keyId\"\x15\n\x13RevokeMyKeyResponse\"-\n\x14ResolveApiKeyRequest\x12\x15\n\x03key\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03key\"{\n\x15ResolveApiKeyResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32\x1a.tars.identity.v1.IdentityR\x08identity\x12*\n\x03key\x18\x02 \x01(\x0b\x32\x18.tars.identity.v1.ApiKeyR\x03key2\xd0\x07\n\tMeService\x12\x8b\x01\n\x05Login\x12\x1e.tars.identity.v1.LoginRequest\x1a\x1f.tars.identity.v1.LoginResponse\"A\x92\xb5\x18\x02(\x01\xa2\xb5\x18\x13Initiate OIDC login\xaa\xb5\x18\x07\x41\x63\x63ount\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/auth/login:\x01*\x12\x90\x01\n\x06Logout\x12\x1f.tars.identity.v1.LogoutRequest\x1a .tars.identity.v1.LogoutResponse\"C\x8a\xb5\x18\x03\n\x01\x03\x92\xb5\x18\x08:\x06logout\xa2\xb5\x18\x07Log out\xaa\xb5\x18\x07\x41\x63\x63ount\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/auth/logout:\x01*\x12\x92\x01\n\x05GetMe\x12\x1e.tars.identity.v1.GetMeRequest\x1a\x1f.tars.identity.v1.GetMeResponse\"H\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x08:\x06whoami\xa2\xb5\x18\x14Get current identity\xaa\xb5\x18\x07\x41\x63\x63ount\x82\xd3\xe4\x93\x02\x08\x12\x06/v1/me\x12\xa8\x01\n\nIssueMyKey\x12#.tars.identity.v1.IssueMyKeyRequest\x1a$.tars.identity.v1.IssueMyKeyResponse\"O\x8a\xb5\x18\x03\n\x01\x03\x92\xb5\x18\x0e:\x04keys:\x06\x63reate\xa2\xb5\x18\x10Issue an API key\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/me/keys:\x01*\x12\xa4\x01\n\nListMyKeys\x12#.tars.identity.v1.ListMyKeysRequest\x1a$.tars.identity.v1.ListMyKeysResponse\"K\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x0c:\x04keys:\x04list\xa2\xb5\x18\rList API keys\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/me/keys\x12\xba\x01\n\x0bRevokeMyKey\x12$.tars.identity.v1.RevokeMyKeyRequest\x1a%.tars.identity.v1.RevokeMyKeyResponse\"^\x8a\xb5\x18\x03\n\x01\x03\x92\xb5\x18\x16\x1a\x06key_id:\x04keys:\x06revoke\xa2\xb5\x18\x11Revoke an API key\xaa\xb5\x18\x08\x41PI Keys\x82\xd3\xe4\x93\x02\x16*\x14/v1/me/keys/{key_id}2\x8f\x01\n\x0fIdentityService\x12|\n\rResolveApiKey\x12&.tars.identity.v1.ResolveApiKeyRequest\x1a\'.tars.identity.v1.ResolveApiKeyResponse\"\x1a\x90\x02\x01\x8a\xb5\x18\r\n\x01\x02\x12\x08internal\x92\xb5\x18\x02(\x01\x42\xcb\x01\n\x14\x63om.tars.identity.v1B\x14IdentityServiceProtoP\x01Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Identity.V1\xca\x02\x10Tars\\Identity\\V1\xe2\x02\x1cTars\\Identity\\V1\\GPBMetadata\xea\x02\x12Tars::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.identity.v1.identity_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.identity.v1B\024IdentityServiceProtoP\001Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\242\002\003TIX\252\002\020Tars.Identity.V1\312\002\020Tars\\Identity\\V1\342\002\034Tars\\Identity\\V1\\GPBMetadata\352\002\022Tars::Identity::V1'
  _globals['_LOGINREQUEST'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_LOGINREQUEST'].fields_by_name['redirect_uri']._serialized_options = b'\340A\002'
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge']._loaded_options = None
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge']._serialized_options = b'\340A\002'
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge_method']._loaded_options = None
  _globals['_LOGINREQUEST'].fields_by_name['code_challenge_method']._serialized_options = b'\340A\002'
  _globals['_LOGINRESPONSE'].fields_by_name['authorization_url']._loaded_options = None
  _globals['_LOGINRESPONSE'].fields_by_name['authorization_url']._serialized_options = b'\340A\003'
  _globals['_LOGINRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_LOGINRESPONSE'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_ISSUEMYKEYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ISSUEMYKEYREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002'
  _globals['_ISSUEMYKEYRESPONSE'].fields_by_name['secret']._loaded_options = None
  _globals['_ISSUEMYKEYRESPONSE'].fields_by_name['secret']._serialized_options = b'\340A\003'
  _globals['_REVOKEMYKEYREQUEST'].fields_by_name['key_id']._loaded_options = None
  _globals['_REVOKEMYKEYREQUEST'].fields_by_name['key_id']._serialized_options = b'\340A\002'
  _globals['_RESOLVEAPIKEYREQUEST'].fields_by_name['key']._loaded_options = None
  _globals['_RESOLVEAPIKEYREQUEST'].fields_by_name['key']._serialized_options = b'\340A\002'
  _globals['_MESERVICE'].methods_by_name['Login']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['Login']._serialized_options = b'\222\265\030\002(\001\242\265\030\023Initiate OIDC login\252\265\030\007Account\202\323\344\223\002\023\"\016/v1/auth/login:\001*'
  _globals['_MESERVICE'].methods_by_name['Logout']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['Logout']._serialized_options = b'\212\265\030\003\n\001\003\222\265\030\010:\006logout\242\265\030\007Log out\252\265\030\007Account\202\323\344\223\002\024\"\017/v1/auth/logout:\001*'
  _globals['_MESERVICE'].methods_by_name['GetMe']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['GetMe']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\010:\006whoami\242\265\030\024Get current identity\252\265\030\007Account\202\323\344\223\002\010\022\006/v1/me'
  _globals['_MESERVICE'].methods_by_name['IssueMyKey']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['IssueMyKey']._serialized_options = b'\212\265\030\003\n\001\003\222\265\030\016:\004keys:\006create\242\265\030\020Issue an API key\252\265\030\010API Keys\202\323\344\223\002\020\"\013/v1/me/keys:\001*'
  _globals['_MESERVICE'].methods_by_name['ListMyKeys']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['ListMyKeys']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\014:\004keys:\004list\242\265\030\rList API keys\252\265\030\010API Keys\202\323\344\223\002\r\022\013/v1/me/keys'
  _globals['_MESERVICE'].methods_by_name['RevokeMyKey']._loaded_options = None
  _globals['_MESERVICE'].methods_by_name['RevokeMyKey']._serialized_options = b'\212\265\030\003\n\001\003\222\265\030\026\032\006key_id:\004keys:\006revoke\242\265\030\021Revoke an API key\252\265\030\010API Keys\202\323\344\223\002\026*\024/v1/me/keys/{key_id}'
  _globals['_IDENTITYSERVICE'].methods_by_name['ResolveApiKey']._loaded_options = None
  _globals['_IDENTITYSERVICE'].methods_by_name['ResolveApiKey']._serialized_options = b'\220\002\001\212\265\030\r\n\001\002\022\010internal\222\265\030\002(\001'
  _globals['_LOGINREQUEST']._serialized_start=299
  _globals['_LOGINREQUEST']._serialized_end=478
  _globals['_LOGINRESPONSE']._serialized_start=480
  _globals['_LOGINRESPONSE']._serialized_end=572
  _globals['_LOGOUTREQUEST']._serialized_start=574
  _globals['_LOGOUTREQUEST']._serialized_end=589
  _globals['_LOGOUTRESPONSE']._serialized_start=591
  _globals['_LOGOUTRESPONSE']._serialized_end=607
  _globals['_GETMEREQUEST']._serialized_start=609
  _globals['_GETMEREQUEST']._serialized_end=623
  _globals['_GETMERESPONSE']._serialized_start=625
  _globals['_GETMERESPONSE']._serialized_end=696
  _globals['_ISSUEMYKEYREQUEST']._serialized_start=699
  _globals['_ISSUEMYKEYREQUEST']._serialized_end=834
  _globals['_ISSUEMYKEYRESPONSE']._serialized_start=836
  _globals['_ISSUEMYKEYRESPONSE']._serialized_end=929
  _globals['_LISTMYKEYSREQUEST']._serialized_start=931
  _globals['_LISTMYKEYSREQUEST']._serialized_end=999
  _globals['_LISTMYKEYSRESPONSE']._serialized_start=1001
  _globals['_LISTMYKEYSRESPONSE']._serialized_end=1117
  _globals['_REVOKEMYKEYREQUEST']._serialized_start=1119
  _globals['_REVOKEMYKEYREQUEST']._serialized_end=1167
  _globals['_REVOKEMYKEYRESPONSE']._serialized_start=1169
  _globals['_REVOKEMYKEYRESPONSE']._serialized_end=1190
  _globals['_RESOLVEAPIKEYREQUEST']._serialized_start=1192
  _globals['_RESOLVEAPIKEYREQUEST']._serialized_end=1237
  _globals['_RESOLVEAPIKEYRESPONSE']._serialized_start=1239
  _globals['_RESOLVEAPIKEYRESPONSE']._serialized_end=1362
  _globals['_MESERVICE']._serialized_start=1365
  _globals['_MESERVICE']._serialized_end=2341
  _globals['_IDENTITYSERVICE']._serialized_start=2344
  _globals['_IDENTITYSERVICE']._serialized_end=2487
# @@protoc_insertion_point(module_scope)



import datetime

from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.cli.v1 import cli_pb2 as _cli_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TelemetryConfig(_message.Message):
    __slots__ = ("id", "user_id", "telemetry_type", "sink_url", "protocol", "auth_type", "auth_value", "api_key_header", "enabled", "last_checked_at", "status", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SINK_URL_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    LAST_CHECKED_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    telemetry_type: str
    sink_url: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    enabled: bool
    last_checked_at: _timestamp_pb2.Timestamp
    status: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., sink_url: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., enabled: _Optional[bool] = ..., last_checked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., status: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateTelemetryConfigRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "telemetry_type", "endpoint", "protocol", "auth_type", "auth_value", "api_key_header", "headers", "enabled")
    class HeadersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    telemetry_type: str
    endpoint: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    headers: _containers.ScalarMap[str, str]
    enabled: bool
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., endpoint: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., headers: _Optional[_Mapping[str, str]] = ..., enabled: _Optional[bool] = ...) -> None: ...

class ListTelemetryConfigsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "telemetry_type", "enabled")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    telemetry_type: str
    enabled: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., enabled: _Optional[str] = ...) -> None: ...

class ListTelemetryConfigsResponse(_message.Message):
    __slots__ = ("configs", "total")
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[TelemetryConfig]
    total: int
    def __init__(self, configs: _Optional[_Iterable[_Union[TelemetryConfig, _Mapping]]] = ..., total: _Optional[int] = ...) -> None: ...

class GetTelemetryConfigRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "config_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    config_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., config_id: _Optional[str] = ...) -> None: ...

class UpdateTelemetryConfigRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "config_id", "endpoint", "protocol", "auth_type", "auth_value", "api_key_header", "enabled", "status")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    config_id: str
    endpoint: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    enabled: str
    status: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., config_id: _Optional[str] = ..., endpoint: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., enabled: _Optional[str] = ..., status: _Optional[str] = ...) -> None: ...

class DeleteTelemetryConfigRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "config_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    config_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., config_id: _Optional[str] = ...) -> None: ...

class SetProjectTelemetryConfigRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "telemetry_type", "endpoint", "protocol", "auth_type", "auth_value", "api_key_header", "enabled")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    telemetry_type: str
    endpoint: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    enabled: bool
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., endpoint: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., enabled: _Optional[bool] = ...) -> None: ...

class GetProjectTelemetryConfigRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "telemetry_type")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    telemetry_type: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ...) -> None: ...



from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IdPrefix(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ID_PREFIX_UNSPECIFIED: _ClassVar[IdPrefix]
    ID_PREFIX_CUSTOMER: _ClassVar[IdPrefix]
    ID_PREFIX_PROJECT: _ClassVar[IdPrefix]
    ID_PREFIX_DATAPLANE: _ClassVar[IdPrefix]
    ID_PREFIX_API_KEY: _ClassVar[IdPrefix]
    ID_PREFIX_OPERATION: _ClassVar[IdPrefix]
    ID_PREFIX_IDENTITY: _ClassVar[IdPrefix]
    ID_PREFIX_BUDGET: _ClassVar[IdPrefix]
    ID_PREFIX_BYOK_KEY: _ClassVar[IdPrefix]
    ID_PREFIX_GATEWAY: _ClassVar[IdPrefix]
    ID_PREFIX_PROJECT_GATEWAY_MAP: _ClassVar[IdPrefix]
    ID_PREFIX_DATAPLANE_CREDENTIAL: _ClassVar[IdPrefix]
    ID_PREFIX_PROVIDER: _ClassVar[IdPrefix]
    ID_PREFIX_MODEL: _ClassVar[IdPrefix]
    ID_PREFIX_BILLING_PLAN: _ClassVar[IdPrefix]
    ID_PREFIX_USAGE_RECORD: _ClassVar[IdPrefix]
    ID_PREFIX_SESSION: _ClassVar[IdPrefix]
    ID_PREFIX_WEBHOOK: _ClassVar[IdPrefix]
ID_PREFIX_UNSPECIFIED: IdPrefix
ID_PREFIX_CUSTOMER: IdPrefix
ID_PREFIX_PROJECT: IdPrefix
ID_PREFIX_DATAPLANE: IdPrefix
ID_PREFIX_API_KEY: IdPrefix
ID_PREFIX_OPERATION: IdPrefix
ID_PREFIX_IDENTITY: IdPrefix
ID_PREFIX_BUDGET: IdPrefix
ID_PREFIX_BYOK_KEY: IdPrefix
ID_PREFIX_GATEWAY: IdPrefix
ID_PREFIX_PROJECT_GATEWAY_MAP: IdPrefix
ID_PREFIX_DATAPLANE_CREDENTIAL: IdPrefix
ID_PREFIX_PROVIDER: IdPrefix
ID_PREFIX_MODEL: IdPrefix
ID_PREFIX_BILLING_PLAN: IdPrefix
ID_PREFIX_USAGE_RECORD: IdPrefix
ID_PREFIX_SESSION: IdPrefix
ID_PREFIX_WEBHOOK: IdPrefix

class PageRequest(_message.Message):
    __slots__ = ("page_size", "page_token", "filter", "order_by")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class PageResponse(_message.Message):
    __slots__ = ("next_page_token",)
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    next_page_token: str
    def __init__(self, next_page_token: _Optional[str] = ...) -> None: ...

class IdempotencyKey(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class Problem(_message.Message):
    __slots__ = ("type", "title", "status", "detail", "instance", "reason", "domain", "metadata", "trace_id")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    INSTANCE_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    TRACE_ID_FIELD_NUMBER: _ClassVar[int]
    type: str
    title: str
    status: int
    detail: str
    instance: str
    reason: str
    domain: str
    metadata: _containers.ScalarMap[str, str]
    trace_id: str
    def __init__(self, type: _Optional[str] = ..., title: _Optional[str] = ..., status: _Optional[int] = ..., detail: _Optional[str] = ..., instance: _Optional[str] = ..., reason: _Optional[str] = ..., domain: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., trace_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/identity/v1/identity.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/identity/v1/identity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftars/identity/v1/identity.proto\x12\x10tars.identity.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x01\n\x0bUserDetails\x12&\n\x0coidc_subject\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0boidcSubject\x12$\n\x0boidc_issuer\x18\x02 \x01(\tB\x03\xe0\x41\x02R\noidcIssuer\x12\x14\n\x05\x65mail\x18\x03 \x01(\tR\x05\x65mail\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12%\n\x0e\x65mail_verified\x18\x05 \x01(\x08R\remailVerified\"9\n\x15ServiceAccountDetails\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\"1\n\rClientDetails\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\"\xf5\x04\n\x08Identity\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\ncustomerId\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32\x1e.tars.identity.v1.IdentityTypeB\x03\xe0\x41\x02R\x04type\x12:\n\x05state\x18\x04 \x01(\x0e\x32\x1f.tars.identity.v1.IdentityStateB\x03\xe0\x41\x03R\x05state\x12\x33\n\x04user\x18\n \x01(\x0b\x32\x1d.tars.identity.v1.UserDetailsH\x00R\x04user\x12R\n\x0fservice_account\x18\x0b \x01(\x0b\x32\'.tars.identity.v1.ServiceAccountDetailsH\x00R\x0eserviceAccount\x12\x39\n\x06\x63lient\x18\x0c \x01(\x0b\x32\x1f.tars.identity.v1.ClientDetailsH\x00R\x06\x63lient\x12\x18\n\x07\x62undles\x18\x14 \x03(\tR\x07\x62undles\x12\x36\n\x14\x63ustomer_memberships\x18\x15 \x03(\tB\x03\xe0\x41\x03R\x13\x63ustomerMemberships\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\x12\x18\n\x07version\x18\x34 \x01(\x03R\x07versionB\t\n\x07\x64\x65tails*\x82\x01\n\x0cIdentityType\x12\x1d\n\x19IDENTITY_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12IDENTITY_TYPE_USER\x10\x01\x12!\n\x1dIDENTITY_TYPE_SERVICE_ACCOUNT\x10\x02\x12\x18\n\x14IDENTITY_TYPE_CLIENT\x10\x03*\x84\x01\n\rIdentityState\x12\x1e\n\x1aIDENTITY_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15IDENTITY_STATE_ACTIVE\x10\x01\x12\x1c\n\x18IDENTITY_STATE_SUSPENDED\x10\x02\x12\x1a\n\x16IDENTITY_STATE_DELETED\x10\x03\x42\xc4\x01\n\x14\x63om.tars.identity.v1B\rIdentityProtoP\x01Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Identity.V1\xca\x02\x10Tars\\Identity\\V1\xe2\x02\x1cTars\\Identity\\V1\\GPBMetadata\xea\x02\x12Tars::Identity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.identity.v1.identity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.identity.v1B\rIdentityProtoP\001Z;github.com/tetrateio/fraser/api/tars/identity/v1;identityv1\242\002\003TIX\252\002\020Tars.Identity.V1\312\002\020Tars\\Identity\\V1\342\002\034Tars\\Identity\\V1\\GPBMetadata\352\002\022Tars::Identity::V1'
  _globals['_USERDETAILS'].fields_by_name['oidc_subject']._loaded_options = None
  _globals['_USERDETAILS'].fields_by_name['oidc_subject']._serialized_options = b'\340A\002'
  _globals['_USERDETAILS'].fields_by_name['oidc_issuer']._loaded_options = None
  _globals['_USERDETAILS'].fields_by_name['oidc_issuer']._serialized_options = b'\340A\002'
  _globals['_IDENTITY'].fields_by_name['id']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['customer_id']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['customer_id']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['type']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['type']._serialized_options = b'\340A\002'
  _globals['_IDENTITY'].fields_by_name['state']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['customer_memberships']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['customer_memberships']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['created_at']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_IDENTITY'].fields_by_name['updated_at']._loaded_options = None
  _globals['_IDENTITY'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_IDENTITYTYPE']._serialized_start=1037
  _globals['_IDENTITYTYPE']._serialized_end=1167
  _globals['_IDENTITYSTATE']._serialized_start=1170
  _globals['_IDENTITYSTATE']._serialized_end=1302
  _globals['_USERDETAILS']._serialized_start=120
  _globals['_USERDETAILS']._serialized_end=292
  _globals['_SERVICEACCOUNTDETAILS']._serialized_start=294
  _globals['_SERVICEACCOUNTDETAILS']._serialized_end=351
  _globals['_CLIENTDETAILS']._serialized_start=353
  _globals['_CLIENTDETAILS']._serialized_end=402
  _globals['_IDENTITY']._serialized_start=405
  _globals['_IDENTITY']._serialized_end=1034
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/tenancy/v1/customer.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/tenancy/v1/customer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etars/tenancy/v1/customer.proto\x12\x0ftars.tenancy.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x81\x04\n\x08\x43ustomer\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x02id\x12$\n\x0b\x63ustomer_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x39\n\x05state\x18\x05 \x01(\x0e\x32\x1e.tars.tenancy.v1.CustomerStateB\x03\xe0\x41\x03R\x05state\x12=\n\x06labels\x18\x06 \x03(\x0b\x32%.tars.tenancy.v1.Customer.LabelsEntryR\x06labels\x12>\n\ncreated_at\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tcreatedAt\x12>\n\nupdated_at\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tupdatedAt\x12@\n\x0b\x61rchived_at\x18\x34 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\narchivedAt\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*g\n\rCustomerState\x12\x1e\n\x1a\x43USTOMER_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43USTOMER_STATE_ACTIVE\x10\x01\x12\x1b\n\x17\x43USTOMER_STATE_ARCHIVED\x10\x02\x42\xbd\x01\n\x13\x63om.tars.tenancy.v1B\rCustomerProtoP\x01Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\xa2\x02\x03TTX\xaa\x02\x0fTars.Tenancy.V1\xca\x02\x0fTars\\Tenancy\\V1\xe2\x02\x1bTars\\Tenancy\\V1\\GPBMetadata\xea\x02\x11Tars::Tenancy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.tenancy.v1.customer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.tenancy.v1B\rCustomerProtoP\001Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\242\002\003TTX\252\002\017Tars.Tenancy.V1\312\002\017Tars\\Tenancy\\V1\342\002\033Tars\\Tenancy\\V1\\GPBMetadata\352\002\021Tars::Tenancy::V1'
  _globals['_CUSTOMER_LABELSENTRY']._loaded_options = None
  _globals['_CUSTOMER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CUSTOMER'].fields_by_name['id']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['id']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CUSTOMER'].fields_by_name['state']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['state']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['created_at']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['created_at']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['updated_at']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['updated_at']._serialized_options = b'\340A\003'
  _globals['_CUSTOMER'].fields_by_name['archived_at']._loaded_options = None
  _globals['_CUSTOMER'].fields_by_name['archived_at']._serialized_options = b'\340A\003'
  _globals['_CUSTOMERSTATE']._serialized_start=633
  _globals['_CUSTOMERSTATE']._serialized_end=736
  _globals['_CUSTOMER']._serialized_start=118
  _globals['_CUSTOMER']._serialized_end=631
  _globals['_CUSTOMER_LABELSENTRY']._serialized_start=574
  _globals['_CUSTOMER_LABELSENTRY']._serialized_end=631
# @@protoc_insertion_point(module_scope)
